@@ -3,7 +3,7 @@ from disk import Path
 from .Cache import Cache
 
 
-def memoize(path, exclude_kwargs=None, s3=None, spark=None, id=0):
+def memoize(path, exclude_kwargs=None, s3=None, spark=None, id=0, echo=1):
 	"""
 	makes a decorator for memoizing a function
 	:type path: amazonian.S3.S3Path or Path or str
@@ -31,7 +31,7 @@ def memoize(path, exclude_kwargs=None, s3=None, spark=None, id=0):
 		:type function: callable
 		:rtype: callable
 		"""
-		cache = Cache(path=path, spark=spark)
+		cache = Cache(path=path, spark=spark, echo=echo)
 
 		if not isinstance(exclude_kwargs, (list, tuple)) and exclude_kwargs is not None:
 			raise TypeError(f'exclude_kwargs is of type {type(exclude_kwargs)}! None, list, and tuple are accepted.')
